From 289490728f230c55f7c9f90389c80289c90fbd6c Mon Sep 17 00:00:00 2001
From: Jelte Fennema-Nio <jelte.fennema@microsoft.com>
Date: Tue, 19 Dec 2023 16:57:45 +0100
Subject: [PATCH v6 4/4] Early exit with pgindent --check when possible

No need to check all the files if we only care about pgindent its exit
code. We can fail at the first file to be done quicker.
---
 src/tools/pgindent/pgindent | 12 +++++++++++-
 1 file changed, 11 insertions(+), 1 deletion(-)

diff --git a/src/tools/pgindent/pgindent b/src/tools/pgindent/pgindent
index 10f8cbaeabf..23bb3eb6ae5 100755
--- a/src/tools/pgindent/pgindent
+++ b/src/tools/pgindent/pgindent
@@ -432,7 +432,17 @@ foreach my $source_filename (@files)
 		}
 		if ($check)
 		{
-			$status = 2;
+			if ($write || $diff)
+			{
+				# We don't want to exit immediately, because we
+				# want to write and/or diff all the files
+				$status = 2;
+			}
+			else
+			{
+				# We're just checking, so we can exit immediately
+				exit 2;
+			}
 		}
 	}
 }
-- 
2.34.1

